[svn-commits] mnicholson: trunk r272368 - in /trunk: ./ apps/app_queue.c

SVN commits to the Digium repositories svn-commits at lists.digium.com
Wed Jun 23 17:36:54 CDT 2010


Author: mnicholson
Date: Wed Jun 23 17:36:49 2010
New Revision: 272368

URL: http://svnview.digium.com/svn/asterisk?view=rev&rev=272368
Log:
Merged revisions 272367 via svnmerge from 
https://origsvn.digium.com/svn/asterisk/branches/1.4

This version of the patch only adds AgentComplete for attended transfers.  It was already present for blind transfers.

........
  r272367 | mnicholson | 2010-06-23 17:33:51 -0500 (Wed, 23 Jun 2010) | 8 lines
  
  Send AgentComplete manager events in the event of blind and attended transfers.
  
  (closes issue #16819)
  Reported by: elbriga
  Patches:
        app_queue.diff uploaded by elbriga (license 482)
........

Modified:
    trunk/   (props changed)
    trunk/apps/app_queue.c

Propchange: trunk/
------------------------------------------------------------------------------
Binary property 'branch-1.4-merged' - no diff available.

Modified: trunk/apps/app_queue.c
URL: http://svnview.digium.com/svn/asterisk/trunk/apps/app_queue.c?view=diff&rev=272368&r1=272367&r2=272368
==============================================================================
--- trunk/apps/app_queue.c (original)
+++ trunk/apps/app_queue.c Wed Jun 23 17:36:49 2010
@@ -4816,7 +4816,8 @@
 		bridge = ast_bridge_call(qe->chan,peer, &bridge_config);
 
 		/* If the queue member did an attended transfer, then the TRANSFER already was logged in the queue_log
 		 * when the masquerade occurred. These other "ending" queue_log messages are unnecessary
 		 */
 		ast_channel_lock(qe->chan);
 		if (!attended_transfer_occurred(qe->chan)) {
@@ -4841,6 +4842,9 @@
 				ast_channel_datastore_remove(qe->chan, tds);
 			}
 			update_queue(qe->parent, member, callcompletedinsl, (time(NULL) - callstart));
+		} else {
+			/* We already logged the TRANSFER on the queue_log, but we still need to send the AgentComplete event */
+			send_agent_complete(qe, queuename, peer, member, callstart, vars, sizeof(vars), TRANSFER);
 		}
 
 		if (transfer_ds) {
@@ -4816,7 +4816,8 @@
 
 		/* If the queue member did an attended transfer, then the TRANSFER already was logged in the queue_log
-		 * when the masquerade occurred. These other "ending" queue_log messages are unnecessary
+		 * when the masquerade occurred. These other "ending" queue_log messages are unnecessary, except for
+		 * the AgentComplete manager event
 		 */
 		ast_channel_lock(qe->chan);




More information about the svn-commits mailing list